package com.ruoyi.bid.mapper;

import java.util.List;
import com.ruoyi.bid.domain.BidZizhi;

/**
 * 资质证书Mapper接口
 * 
 * @author ruoyi
 * @date 2025-12-10
 */
public interface BidZizhiMapper 
{
    /**
     * 查询资质证书
     * 
     * @param id 资质证书主键
     * @return 资质证书
     */
    public BidZizhi selectBidZizhiById(Long id);

    /**
     * 查询资质证书列表
     * 
     * @param bidZizhi 资质证书
     * @return 资质证书集合
     */
    public List<BidZizhi> selectBidZizhiList(BidZizhi bidZizhi);

    /**
     * 新增资质证书
     * 
     * @param bidZizhi 资质证书
     * @return 结果
     */
    public int insertBidZizhi(BidZizhi bidZizhi);

    /**
     * 修改资质证书
     * 
     * @param bidZizhi 资质证书
     * @return 结果
     */
    public int updateBidZizhi(BidZizhi bidZizhi);

    /**
     * 删除资质证书
     * 
     * @param id 资质证书主键
     * @return 结果
     */
    public int deleteBidZizhiById(Long id);

    /**
     * 批量删除资质证书
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBidZizhiByIds(Long[] ids);
}
